==> smarthse-fwgj-api-1.0.0-sources.jar: cn/smarthse/fwgj/model/param/check/AddCheckInfoParam.java <==

package cn.smarthse.fwgj.model.param.check;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;


/**
 * 新增巡查记录参数(企业信息部分)
 * @author chuhy
 * @since 2023-03-08 11:01
 */
@Data
public class AddCheckInfoParam implements Serializable{
	private static final long serialVersionUID = -6215703429868838755L;

	
	/**
	 * 单位id
	 */
    @ApiModelProperty(value="单位id")
	private Long cid;

	/**
	 * 巡查员账号id
	 */
	@ApiModelProperty(value="巡查员账号id")
	private Long userId;
	
	/**
	 * 单位名称
	 */
    @ApiModelProperty(value="单位名称")
	private String unitName;
	
	/**
	 * 单位营业状态
	 */
    @ApiModelProperty(value="单位营业状态")
	private Integer unitStatus;
	
	/**
	 * 主要负责人
	 */
    @ApiModelProperty(value="主要负责人")
	private String manager;
	
	/**
	 * 联系电话
	 */
    @ApiModelProperty(value="联系电话")
	private String tel;
	
	/**
	 * 职业健康管理人员
	 */
    @ApiModelProperty(value="职业健康管理人员")
	private String hseManager;
	
	/**
	 * 职业健康管理人员-联系电话
	 */
    @ApiModelProperty(value="职业健康管理人员-联系电话")
	private String hesTel;
	
	/**
	 * 行政区划地址
	 */
    @ApiModelProperty(value="行政区划地址")
	private String address;
	
	/**
	 * 工作场所地址
	 */
    @ApiModelProperty(value="工作场所地址")
	private String workAddress;
	
	/**
	 * 行政区划
	 */
    @ApiModelProperty(value="行政区划")
	private Long areaId;
	
	/**
	 * 行业编码
	 */
    @ApiModelProperty(value="行业编码")
	private String industryCode;
	
	/**
	 * 行业名
	 */
    @ApiModelProperty(value="行业名")
	private String industryName;
	
	/**
	 * 规模
	 */
    @ApiModelProperty(value="规模")
	private String scaleCode;
	
	/**
	 * 经济
	 */
    @ApiModelProperty(value="经济")
	private String economyCode;

	/**
	 * 经济名称
	 */
	@ApiModelProperty(value="经济名称")
	private String economyName;
	
	/**
	 * 巡查年份
	 */
    @ApiModelProperty(value="巡查年份")
	private Integer year;
	
	/**
	 * 巡查人
	 */
    @ApiModelProperty(value="巡查人")
	private String patrolPeople;
	
	/**
	 * 巡查时间
	 */
    @ApiModelProperty(value="巡查时间")
	private Date patrolTime;
	
	/**
	 * 巡查痕迹附件
	 */
    @ApiModelProperty(value="巡查痕迹附件")
	private String patrolFile;

	/**
	 * 巡查状态(0-未开始；1-进行中(存草稿)；2-已完成；3-已终止)
	 */
	@ApiModelProperty(value="巡查状态(0-未开始；1-进行中(存草稿)；2-已完成；3-已中止)")
	private Integer patrolStatus;

	/**
	 * 中止类型(1-企业暂停；2-企业关闭；3-区域变更)
	 */
	@ApiModelProperty(value="中止类型(1-企业暂停；2-企业关闭；3-区域变更)")
	private Integer stopType;



}

==> smarthse-fwgj-api-2.0.0-sources.jar: cn/smarthse/fwgj/model/param/check/AddCheckInfoParam.java <==
package cn.smarthse.fwgj.model.param.check;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 新增巡查记录参数(企业信息部分)
 * @author chuhy
 * @since 2023-03-08 11:01
 */
@Data
public class AddCheckInfoParam implements Serializable{
	private static final long serialVersionUID = -6215703429868838755L;

	
	/**
	 * 单位id
	 */
    //@ApiModelProperty="单位id")
	private Long cid;

	/**
	 * 巡查员账号id
	 */
	//@ApiModelProperty="巡查员账号id")
	private Long userId;
	
	/**
	 * 单位名称
	 */
    //@ApiModelProperty="单位名称")
	private String unitName;
	
	/**
	 * 单位营业状态
	 */
    //@ApiModelProperty="单位营业状态")
	private Integer unitStatus;
	
	/**
	 * 主要负责人
	 */
    //@ApiModelProperty="主要负责人")
	private String manager;
	
	/**
	 * 联系电话
	 */
    //@ApiModelProperty="联系电话")
	private String tel;
	
	/**
	 * 职业健康管理人员
	 */
    //@ApiModelProperty="职业健康管理人员")
	private String hseManager;
	
	/**
	 * 职业健康管理人员-联系电话
	 */
    //@ApiModelProperty="职业健康管理人员-联系电话")
	private String hesTel;
	
	/**
	 * 行政区划地址
	 */
    //@ApiModelProperty="行政区划地址")
	private String address;
	
	/**
	 * 工作场所地址
	 */
    //@ApiModelProperty="工作场所地址")
	private String workAddress;
	
	/**
	 * 行政区划
	 */
    //@ApiModelProperty="行政区划")
	private Long areaId;
	
	/**
	 * 行业编码
	 */
    //@ApiModelProperty="行业编码")
	private String industryCode;
	
	/**
	 * 行业名
	 */
    //@ApiModelProperty="行业名")
	private String industryName;
	
	/**
	 * 规模
	 */
    //@ApiModelProperty="规模")
	private String scaleCode;
	
	/**
	 * 经济
	 */
    //@ApiModelProperty="经济")
	private String economyCode;

	/**
	 * 经济名称
	 */
	//@ApiModelProperty="经济名称")
	private String economyName;
	
	/**
	 * 巡查年份
	 */
    //@ApiModelProperty="巡查年份")
	private Integer year;
	
	/**
	 * 巡查人
	 */
    //@ApiModelProperty="巡查人")
	private String patrolPeople;
	
	/**
	 * 巡查时间
	 */
    //@ApiModelProperty="巡查时间")
	private Date patrolTime;
	
	/**
	 * 巡查痕迹附件
	 */
    //@ApiModelProperty="巡查痕迹附件")
	private String patrolFile;

	/**
	 * 巡查状态(0-未开始；1-进行中(存草稿)；2-已完成；3-已终止)
	 */
	//@ApiModelProperty="巡查状态(0-未开始；1-进行中(存草稿)；2-已完成；3-已中止)")
	private Integer patrolStatus;

	/**
	 * 中止类型(1-企业暂停；2-企业关闭；3-区域变更)
	 */
	//@ApiModelProperty="中止类型(1-企业暂停；2-企业关闭；3-区域变更)")
	private Integer stopType;



}
